@@ -15,9 +15,16 @@ from run_markdown import get_logic_block_from_md_file
 async def main():
     assert len(sys.argv) > 1
     target_file = sys.argv[1]
+    timeout = 1
+    if len(sys.argv) > 2:
+        timeout_str = sys.argv[2]
+        try:
+            timeout = float(timeout_str)
+        except ValueError:
+            raise ValueError(f'Failed to convert {timeout_str!r} to float timeout') from None
     block = get_logic_block_from_md_file(target_file)
     try:
-        await block.evaluate()
+        await block.evaluate(timeout=timeout)
     except Exception as e:
         print("CHECK FAILED")
         print(repr(e))
